@@ -12,13 +12,12 @@ from django.core.exceptions import ImproperlyConfigured
 
 logger = logging.getLogger('django.contrib.gis')
 
-# Custom library path set?
 if 'linux' in sys.platform:
     lib_path = os.path.join(sys.prefix, 'lib', 'libgdal.so')
 elif 'darwin' in sys.platform:
-    lib_path = os.path.join(sys.prefix, 'lib', 'libgdal.dylib')
+    lib_path = os.path.join(sys.prefix, 'lib', 'libgdal.1.dylib')
 elif os.name == 'nt':
-    lib_path = os.path.join(sys.prefix, 'Library', 'bin', 'gdal201.dll')
+    lib_path = os.path.join(sys.prefix, 'Library', 'bin', 'gdal111.dll')
 
 if lib_path:
     lib_names = None
@@ -27,8 +26,7 @@ elif os.name == 'nt':
     lib_names = ['gdal111', 'gdal110', 'gdal19', 'gdal18', 'gdal17']
 elif os.name == 'posix':
     # *NIX library names.
-    lib_names = ['gdal', 'GDAL', 'gdal1.11.0', 'gdal1.10.0', 'gdal1.9.0',
-        'gdal1.8.0', 'gdal1.7.0']
+    lib_names = ['gdal', 'GDAL', 'gdal1.11.0', 'gdal1.10.0', 'gdal1.9.0', 'gdal1.8.0', 'gdal1.7.0']
 else:
     raise GDALException('Unsupported OS "%s"' % os.name)
 
@@ -41,9 +39,10 @@ if lib_names:
             break
 
 if lib_path is None:
-    raise GDALException('Could not find the GDAL library (tried "%s"). '
-                       'Try setting GDAL_LIBRARY_PATH in your settings.' %
-                       '", "'.join(lib_names))
+    raise GDALException(
+        'Could not find the GDAL library (tried "%s"). Try setting '
+        'GDAL_LIBRARY_PATH in your settings.' % '", "'.join(lib_names)
+    )
 
 # This loads the GDAL/OGR C library
 lgdal = CDLL(lib_path)
@@ -106,7 +105,7 @@ CPLErrorHandler = CFUNCTYPE(None, c_int, c_int, c_char_p)
 
 
 def err_handler(error_class, error_number, message):
-    logger.error('GDAL_ERROR %d: %s' % (error_number, message))
+    logger.error('GDAL_ERROR %d: %s', error_number, message)
 err_handler = CPLErrorHandler(err_handler)
 
 
